@@ -10,18 +10,20 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import logging
 import os.path
 
-from reno import defaults
-from reno import formatter
-from reno import loader
-
 from docutils import nodes
 from docutils.parsers import rst
 from docutils.parsers.rst import directives
-from docutils.statemachine import ViewList
+from docutils import statemachine
 from sphinx.util.nodes import nested_parse_with_titles
 
+from reno import config
+from reno import defaults
+from reno import formatter
+from reno import loader
+
 
 class ReleaseNotesDirective(rst.Directive):
 
@@ -35,6 +37,7 @@ class ReleaseNotesDirective(rst.Directive):
         'version': directives.unchanged,
         'collapse-pre-releases': directives.flag,
         'earliest-version': directives.unchanged,
+        'stop-at-branch-base': directives.flag,
     }
 
     def run(self):
@@ -50,24 +53,29 @@ class ReleaseNotesDirective(rst.Directive):
         reporoot = os.path.abspath(reporoot_opt)
         relnotessubdir = self.options.get('relnotessubdir',
                                           defaults.RELEASE_NOTES_SUBDIR)
-        notessubdir = self.options.get('notesdir', defaults.NOTES_SUBDIR)
+        conf = config.Config(reporoot, relnotessubdir)
+        opt_overrides = {}
+        if 'notesdir' in self.options:
+            opt_overrides['notesdir'] = self.options.get('notesdir')
         version_opt = self.options.get('version')
-        # FIXME(dhellmann): Force this flag True for now and figure
+        # FIXME(dhellmann): Force these flags True for now and figure
         # out how Sphinx passes a "false" flag later.
-        collapse = True  # 'collapse-pre-releases' in self.options
-        earliest_version = self.options.get('earliest-version')
+        # 'collapse-pre-releases' in self.options
+        opt_overrides['collapse_pre_releases'] = True
+        opt_overrides['stop_at_branch_base'] = True
+        if 'earliest-version' in self.options:
+            opt_overrides['earliest_version'] = self.options.get(
+                'earliest-version')
+        if branch:
+            opt_overrides['branch'] = branch
+        conf.override(**opt_overrides)
 
-        notesdir = os.path.join(relnotessubdir, notessubdir)
+        notesdir = os.path.join(relnotessubdir, conf.notesdir)
         info('scanning %s for %s release notes' %
-             (os.path.join(reporoot, notesdir), branch or 'current branch'))
+             (os.path.join(conf.reporoot, notesdir),
+              branch or 'current branch'))
 
-        ldr = loader.Loader(
-            reporoot=reporoot,
-            notesdir=notesdir,
-            branch=branch,
-            collapse_pre_releases=collapse,
-            earliest_version=earliest_version,
-        )
+        ldr = loader.Loader(conf)
         if version_opt is not None:
             versions = [
                 v.strip()
@@ -75,13 +83,14 @@ class ReleaseNotesDirective(rst.Directive):
             ]
         else:
             versions = ldr.versions
+        info('got versions %s' % (versions,))
         text = formatter.format_report(
             ldr,
             versions,
             title=title,
         )
         source_name = '<' + __name__ + '>'
-        result = ViewList()
+        result = statemachine.ViewList()
         for line in text.splitlines():
             result.append(line, source_name)
 
@@ -93,3 +102,8 @@ class ReleaseNotesDirective(rst.Directive):
 
 def setup(app):
     app.add_directive('release-notes', ReleaseNotesDirective)
+
+    logging.basicConfig(
+        level=logging.INFO,
+        format='[%(name)s] %(message)s',
+    )
